<?php

namespace Litecms\Image\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litecms\Image\Interfaces\ImageRepositoryInterface;

class ImagePublicController extends BaseController
{
    // use ImageWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litecms\Image\Interfaces\ImageRepositoryInterface $image
     *
     * @return type
     */
    public function __construct(ImageRepositoryInterface $image)
    {
        $this->repository = $image;
        parent::__construct();
    }

    /**
     * Show image's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $images = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$image::$image.names'))
            ->view('$image::public.image.index')
            ->data(compact('$images'))
            ->output();
    }

    /**
     * Show image's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $images = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$image::$image.names'))
            ->view('$image::public.image.index')
            ->data(compact('$images'))
            ->output();
    }

    /**
     * Show image.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $image = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$image->name . trans('$image::$image.name'))
            ->view('$image::public.image.show')
            ->data(compact('$image'))
            ->output();
    }

}
