<?php

namespace Litecms\Image\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Image\Models\Image;

class ImagePolicy
{

    /**
     * Determine if the given user can view the image.
     *
     * @param UserPolicy $user
     * @param Image $image
     *
     * @return bool
     */
    public function view(UserPolicy $user, Image $image)
    {
        if ($user->canDo('image.image.view') && $user->isAdmin()) {
            return true;
        }

        return $image->user_id == user_id() && $image->user_type == user_type();
    }

    /**
     * Determine if the given user can create a image.
     *
     * @param UserPolicy $user
     * @param Image $image
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('image.image.create');
    }

    /**
     * Determine if the given user can update the given image.
     *
     * @param UserPolicy $user
     * @param Image $image
     *
     * @return bool
     */
    public function update(UserPolicy $user, Image $image)
    {
        if ($user->canDo('image.image.edit') && $user->isAdmin()) {
            return true;
        }

        return $image->user_id == user_id() && $image->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given image.
     *
     * @param UserPolicy $user
     * @param Image $image
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Image $image)
    {
        return $image->user_id == user_id() && $image->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given image.
     *
     * @param UserPolicy $user
     * @param Image $image
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Image $image)
    {
        if ($user->canDo('image.image.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given image.
     *
     * @param UserPolicy $user
     * @param Image $image
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Image $image)
    {
        if ($user->canDo('image.image.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
